Stan Math Library: stan/math/prim/scal/prob/pareto_type_2_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

pareto_type_2_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_PARETO_TYPE_2_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_PARETO_TYPE_2_RNG_HPP
3
4 #include <boost/random/variate_generator.hpp>
5 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
6 #include <stan/math/prim/scal/err/check_finite.hpp>
7 #include <stan/math/prim/scal/err/check_greater_or_equal.hpp>
8 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
9 #include <stan/math/prim/scal/err/check_not_nan.hpp>
10 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
11 #include <stan/math/prim/scal/fun/constants.hpp>
12 #include <stan/math/prim/scal/fun/value_of.hpp>
13 #include <stan/math/prim/scal/fun/log1m.hpp>
14 #include <stan/math/prim/scal/prob/uniform_rng.hpp>
15
16
17 namespace stan {
18 namespace math {
19
20 template <class RNG>
21 inline double
22 pareto_type_2_rng(const double mu,
23 const double lambda,
24 const double alpha,
25 RNG& rng) {
26 static const char* function("stan::math::pareto_type_2_rng");
27
28 stan::math::check_positive(function, "scale parameter", lambda);
29
30 double uniform_01 = stan::math::uniform_rng(0.0, 1.0, rng);
31
32
33 return (std::pow(1.0 - uniform_01, -1.0 / alpha) - 1.0) * lambda + mu;
34 }
35 }
36 }
37 #endif
check_not_nan.hpp
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::pareto_type_2_rng
double pareto_type_2_rng(const double mu, const double lambda, const double alpha, RNG &rng)
Definition: pareto_type_2_rng.hpp:22
uniform_rng.hpp
check_nonnegative.hpp
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
stan::math::uniform_rng
double uniform_rng(const double alpha, const double beta, RNG &rng)
Definition: uniform_rng.hpp:21
log1m.hpp
constants.hpp
check_finite.hpp
stan::math::pow
fvar< T > pow(const fvar< T > &x1, const fvar< T > &x2)
Definition: pow.hpp:18
check_greater_or_equal.hpp
value_of.hpp
check_consistent_sizes.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.